public class Source
{
  /**
   * Javadoc for method2
   * Another line of javadoc
   */    
  @Version("1.2"
// line comment
// line comment
  )
  @Deprecated
  protected final T method2() throws Exception
  {
    
  }

  /**
   * Javadoc for method1
   * Another line of javadoc
   */
  @Version("1.1"
// line comment
// line comment
  )
  @Deprecated
  public static List< ? extends Serializable > method1() 
  {
    // line comment
    // line comment
  }
}

private enum Source1
{
  ;

  /**
   * Javadoc 3
   */
  @Deprecated
  @Version("1.1"
// line comment
// line comment
  )
  public <T0_3, T1_3> ReturnType3 method_3(Type0_3 param0_3, Type1_3 param1_3) throws Exception0_3 
  {
  // body 3
  }
}
